__code__='Gat=(s)6@U\'RuIZTe-\\a;IF;p4;_9\\Bb!soVJ2L=64-8$<fo_GYfUqaY-"[5)rFqj9\')rpm?dcOqoe]ifd>sFL=A,1BA_PBI!PG!#\\O\'Rd.IcPl5p@X$Ut,W;#g[1"cgV4(^Z9*Ne)*qIt;D9d]Wu@!6tVR!7(Yj""jR+!hKQX#P\\nhH,\'f<97S)d/d#D_>QMJ?GT#uXi$X%V!C$bc%.G1nFhl<(D\\1*G=&%h\'o]J+,K=Dp=c%0]9!pP6*KB";7f71^-V#rB-h$*_.V2e*a9c17P,TB3L(e17*aCCF:?eOQn$:b(ZC$h"u;<^NRWOIHcl#G\'nVDug-LSs:ul8"CGjUuMXi:<?aBFB.9A.TBPSq(_.1JKB&4)i]"r*d9=E+P(6Lt%a$,j_#,\'SG-ifQd+s^Y*t@[b57^F,%Ple=kHIiJFrr;:<aiC6m=-$R>%Z?Grfq/N@oLZ>I:NL:rPrNbQkMQ+#A3%>JATaGDOdmoI,%ms[bA;5]lI(`b!(A%&ZG^&65hk;d%OH!B5rYq22o,o_/UhChn#=qILg=9a=ZZk)1*9u;tSm,Mjp-Io^#T;AgpDmS:M.ENe))[*((CL8=(.Lr8<Ps65sbW:aO1RVm0p;8J+_gajhA*&G_&k=]W\'&C2C_3&oIm?rC7>3A+n3X5lp?=>4FE6F0FZ0.FoIG]9+p@cDBKK@CV2_/,nal@saUF\\Vl$-0E;lBJ9^p"%BF_W89Do"hE1EG)R@[!UWu1&-h"I9@uLWjBo$,gkn$$1#=9H.#O.n/am[J&C\'JC/Q\'MmA?B,n!35YU2tBS7(].U?CAOa2s4nfGN\\B7qE;@crVZu%5?(;%c122&:K&j\'P[mpj^#-Ha/%USX]KRWREILp0:q>+n$/,!r&rk;AN:u7QVlk9Tkk?W8r>+[BG[$G\\IWs&<bcG"[G<:`sM&!gEp)C.nA:)k9pVPo"A7UR"+1a,b/?snglFtL"Co_G3r&%3_k19&pfZs6rWWo6ahS\\0F6(N!-L:3XlIXe5Q<JM1H8CM!of-Fri96oSX9MTr_=E.`"YHr,e3hZX7SaT?WL@+fJ[fo\'b,c%K*b%WEVb)E_J/%`#uj8OnD2[,dF5)!kinl+52IV\'5c/XKgLCb:GHdJBL8X,RkACA\\GRc_9"~>'



__code__='Gas1];/[+<&>$Qs4,unKR$<mPaq[Mf=6^Y/79*>f7E/;h*&k`"OD/jKgh`,ukIY5BSN*P:\'VrJ8O7[A_BA@;&7@uV^\\K`_+Z$/_(h3m`$)=P%a_qaE9c(A[HJ!%R:0F%:i"X(T"@!c_*=F_*)%(qu+%ak?Q@00V_28D92!al+L&[2Rd%WDaD"2OMY(B@Zi(BN9@QN3?Q56SV-p^uH)J6)_8!W3Z$.c<2"cN(-^bCu90F$9Hg.f;oo(6!#Ol^WO55h=lG"S(affR.,D$Y$RG5Nc"dPf!qIFhYr9VE\\F\\=V]#Cb+].kCJ5J!ZApjF`[:^*FY"i[CZq7!YZ8si"0?Kt"<7`Xr7V8_E(%TS&BZHhK,3!t=_+K@3&2V%:q6pNk-4nPr\'WEdcFLD^GN85In4EZ=UF.\'<?eCLpdoti@Bt:/g.Yr2eb,nWtgUW,\\F->sMNNMD?:^p%\\T+r*`R9&0\'X3R_dYF@#V>OHU23XF4&F=RjK8Ifed8[tpf_a$%I>I6e1D)t6Tp^Pi7]SUad]]m"k(oJO\\QX\':8e-f&I<0Q;KdQ+YTL7;d/1n,dG2BRlIft.,a-F(u$Dp-uS4<<*@C3t+@pbGGfg5.!d?eb,ESDUL#anOWZ_81\\tMTsN&Er:1AfRu7)A57X3$`BR+ilI.F/S@YJ#g89m_uBcm+U)!_1rr^DYu9%==6+#kpG0AO5LXO6]D53Qqbj8\\R>tc]8YXW\\Y3U`,`a%LLl?f1\'iC8""(J!2S^767J][r/R;:ruiq7Br_*=?$nNmHUrIHNMJqffcfGCT9IhL(d":Jo[e/QLkcPYhC*0DdMlnB!*g-S[%Hj/$q0,adF2C\\bTjh[?0LWe7ZAk\\\':_T@Ns\\.jagRmnpOk[aQ40DgObuOb8,)Rak9Ja7nXtefID4WWIT^57?JTB[L#bo>R_2qK\'a%^1&t5\'ZKt=)Ls\\7[ZVjCbb4^($(HXi`3>I_herpN9t-M_XSAN56nW*?>iiWd(5f`DKN=4%9;iUj$6;tdFW1(-lZuu1:^+/D\\9T[QEg#Qo0,OMCAQAs4T3Cg*%k%5MOi,YO\\O:G:^*jacrJ^1[@p.<@IfZ;fA:F~>'



__code__='Gas1]?ZX[c&Dr[^a"_:I9hPFO;5(Ae6Y.C)l#\\tW1+!]I\'K:YqF@82/7=.ToA4`<:M5(AQ@AY^V,5iGY(jbSYkYl[?Mn%-MF165)g\\q(o=80>A@IA>nk)V@j^W>=jn,Ro(!=80%fU`r<$\'53`J/?\\l5oP819L&ui!S@N[!,MZg!k&-U!A4De#Ik1e*j>bA5%#2r!oOFD#CmTk56Ulin7070!\'^Y""F(gR1VbNZErNVk>k`]Z"MYSY"^V:AP;A:9a9J0%+C=sH>L+jF7dN%kkFAPB3F%88mu(([L%>J:Fb*esXGW[V4K:Zjl?FVj1\\pL<B.6,Q_pFnW>;R9U#7TO2LBJS)\\G4JT%<,"YA.Zm4IfN[%4(abS2W35<lu)2?\\="]G6rJ/nfS7@*s*F*O5\'f29]RK>Kj.9C+lq/:3Xic?F[V02$8p&B/X^&k-V+=4"SF:dDG4I#Z(?P27Wf#n;X5N;$B?e!CcW/VimIVbeMY$gX4,qY0N_1P>\\?qdD5dWs]F@9PS3E\\iH/`0?UZ1S"#mJGoX-S_fkI/h/2LegfGS)PpG3O?e]qdqN=RjI$]G=SE;_gWl;<,";D[Q!"i,<O\'8^lG0d-FlN+;a_7545H=rgXA4\\Y2;H+4EOQ1)$enkR#W2V0SaQ)X<.T8,g]DWfVu1<1lE&VKkY`&?Q^\\k+H(j,@Wdb^29Br7rbha%@FtMIo\\1ds]i!^=<&nTge\'qE]W:[(TL0IoR972Kj(+<1m=kjpkM%6I;B?.&k[A-5+FuE4V?B@g8!]PkjnuWiiDpZ"8o:+KYf"U7j-Umb<j^Fm[8qNEC>5r/1Hl7q>jG\\hWE+f+UEdP5?R"8I`_EAe)8\',Z)6/$M6Mf.@sqE%s.$/HWW032D\'RKMrJ+GqIcd*G.m5"bSFSieU9,8j6UUlXl?;&WLfHECVi=Nt$$%[lQ_/?%a+H6QYsYft2>MI_\\aoL-&pWtLg;c;`\'_)l$6Y/S8-9^8O1lMWl\']\\SV,-i\\!$\\<Me%SWl+9l:K0lu<k7/c5o^P;KkrJ]fnd!TkG?fa`IVKd<C-Y_QEp2^WP3i>n9gWs\'Gm3r_X->m75U!R!AaUafD~>'
